@@ -20,7 +20,7 @@ License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 """
 
-__version__ = "0.3.5"
+__version__ = "0.3.6"
 
 from libxml2dom.macrolib import *
 from libxml2dom.macrolib import \
@@ -293,6 +293,10 @@ class Node(object):
         else:
             return Node(Node_importNode_DOM(self._node, node, deep), self.ownerDocument)
 
+    def cloneNode(self, deep):
+        # This takes advantage of the ubiquity of importNode (in spite of the DOM specification).
+        return self.importNode(self, deep)
+
     def insertBefore(self, tmp, oldNode):
         if hasattr(tmp, "as_native_node"):
             return Node(Node_insertBefore(self._node, tmp.as_native_node(), oldNode.as_native_node()), self.ownerDocument)
