@@ -21,7 +21,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 """
 
 import xml.dom
-import libxml2mod
+
+# Try the conventional import first.
+
+try:
+    import libxml2mod
+except ImportError:
+    from libxmlmods import libxml2mod
 
 # NOTE: libxml2 seems to use UTF-8 throughout.
 
